# Payz SDK

## Project Overview
The Payz SDK is a software development kit that provides a set of tools and utilities for integrating with the Payz payment gateway.

## Table of Contents
- [Getting Started](#getting-started)
  - [Installation](#installation)
- [Features](#features)
- [Contributing](#contributing)
- [License](#license)

## Getting Started
This section provides instructions on how to get started with the Payz SDK.

## Features
This section describes the main features and capabilities of the Payz SDK.

### Feature 1: Create payment widget

```php
use Payz\Widget;

$widget = new Widget(1, 'secret_key');

$url = $widget->cretePayment(
  'client@mail.ru',
  'Xiaomi 9T',
  1000,
  1,
  'Hello thanks for order',
  'Xiaomi 9T',
  'USDT',
  'rub',
  'ru'
); // Returns payment url
```
More information about the parameters can be found in the [documentation](https://payz.team/api_for_payments#instr-api-pop).

### Feature 2: Verify payment

```php
use Payz\Webhook;

$payment = new Webhook($_POST);
if ($payment->isVerified('secret_key') && $payment->isSuccess()) {
    // Payment success logic
    //F.e:
    $client = $payment->getClient(); // Get client email
    User::where('email', $client)
        ->update(['balance' => $payment->getAmount()]);
}
``` 
### Feature 3: Payouts

```php
use Payz\Payout;

$payout = new Payout($merchantId, $secretKey);

$payout->cryptoPay($address, $amount, $currency);

```
More information about the parameters can be found in the [documentation](https://payz.team/api_for_payments).

## Contributing
We welcome contributions from the developer community to improve the Payz SDK. If you are interested in contributing to the Payz SDK, please follow the steps below:

1. Fork the repository on GitHub.
2. Create a new branch for your feature or bug fix.
3. Make the necessary changes in your branch.
4. Write tests to ensure the changes are working as expected.
5. Submit a pull request with your changes.

## License
The Payz SDK is licensed under the [MIT License](LICENSE).
